==> gottet-1.1.1-1-src.tar.xz: gottet-1.1.1/translations/gottet_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="103"/>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="103"/>
        <source>End the current game?</source>
        <translation>Baigti dabartinį žaidimą?</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="189"/>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Pauzė&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Spustelėkite, norėdami tęsti žaidimą.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="419"/>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Žaidimas Baigtas!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Spustelėkite, norėdami pradėti naują žaidimą.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos Kalba&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Prašome paleisti programą iš naujo, kad įsigaliotų kalbos pakeitimai</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Gottet Scores</source>
        <translation>Gottet Surinkti Taškai</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Level</source>
        <translation>Lygis</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Lines</source>
        <translation>Eilutės</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>Taškai</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="52"/>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="30"/>
        <location filename="../src/window.cpp" line="219"/>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="88"/>
        <source>Click to start a new game.</source>
        <translation>Spustelėkite, norėdami pradėti naują žaidimą.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="106"/>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="107"/>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <source>&amp;Pause</source>
        <translation>Pau&amp;zė</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <location filename="../src/window.cpp" line="110"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="110"/>
        <source>&amp;Resume</source>
        <translation>&amp;Tęsti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;Scores</source>
        <translation>&amp;Surinkti Taškai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="115"/>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="118"/>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="119"/>
        <source>Application &amp;Language...</source>
        <translation>Programos &amp;Kalba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="124"/>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="139"/>
        <source>Next Piece</source>
        <translation>Kita Figūra</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="141"/>
        <source>Level</source>
        <translation>Lygis</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>Removed Lines</source>
        <translation>Pašalinta Eilučių</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>Score</source>
        <translation>Surinkta taškų</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="218"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="220"/>
        <source>A tetris clone I made for my wife</source>
        <translation>Tetris klonas, kurį sukūriau savo žmonai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="221"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Autorinės Teisės &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>

==> gottet-1.1.3-1-src.tar.xz: gottet-1.1.3/translations/gottet_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Baigti dabartinį žaidimą?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Pauzė&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Spustelėkite, norėdami tęsti žaidimą.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Žaidimas baigtas!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Spustelėkite, norėdami pradėti naują žaidimą.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Prašome paleisti programą iš naujo, kad įsigaliotų kalbos pakeitimai</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Gottet surinkti taškai</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Lygis</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Eilutės</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Taškai</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Spustelėkite, norėdami pradėti naują žaidimą.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pau&amp;zė</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Tęsti</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Surinkti taškai</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos &amp;kalba</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Kita figūra</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Lygis</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Pašalinta eilučių</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Surinkta taškų</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Tetris klonas, kurį sukūriau savo žmonai</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Autorių Teisės &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>
